@@ -1,4 +1,4 @@
-# Copyright (c) 1998-2005 by Jonathan Swartz. All rights reserved.
+# Copyright (c) 1998-2002 by Jonathan Swartz. All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -30,12 +30,8 @@ sub get
 
     if (Cache::BaseCache::Object_Has_Expired($object))
     {
-	if ($params{busy_lock}) {
-	    # If busy_lock value provided, set a new "temporary"
-	    # expiration time that many seconds forward, and return
-	    # undef so that this process will start recomputing.
-	    my $busy_lock_time = Cache::BaseCache::Canonicalize_Expiration_Time($params{busy_lock});
-	    $object->set_expires_at(time + $busy_lock_time);
+	if (my $duration = $params{busy_lock}) {
+	    $object->set_expires_at(time + $duration);
 	    $self->set_object($key, $object);
 	} else {
 	    $self->remove($key);
@@ -93,16 +89,16 @@ An object of this class is returned from L<$m-E<gt>cache|HTML::Mason::Request/it
 
 =over
 
-=item clear ()
-
 =for html <a name="item_clear"></a>
 
+=item clear ()
+
 Remove all values in the cache.
 
-=item get (key, [%params])
-
 =for html <a name="item_get"></a>
 
+=item get (key, [%params])
+
 Returns the value associated with I<key> or undef if it is
 non-existent or expired. This is extended with the following optional
 name/value parameters:
@@ -125,10 +121,10 @@ the value.
 
 =back
 
-=item get_object (key)
-
 =for html <a name="item_get_object"></a>
 
+=item get_object (key)
+
 Returns the underlying C<Cache::Object> object associated with I<key>.
 The most useful methods on this object are
 
@@ -136,25 +132,25 @@ The most useful methods on this object are
     $co->get_accessed_at();   # when was object last accessed
     $co->get_expires_at();    # when does object expire
 
-=item expire (key)
-
 =for html <a name="item_expire"></a>
 
+=item expire (key)
+
 Expires the value associated with I<key>, if it exists. Differs from
 L<remove|HTML::Mason::Cache::BaseCache/item_remove> only in that
 the cache object is left around, e.g. for retrieval by
 L<get_object|HTML::Mason::Cache::BaseCache/item_get_object>.
 
-=item remove (key)
-
 =for html <a name="item_remove"></a>
 
+=item remove (key)
+
 Removes the cache object associated with I<key>, if it exists.
 
-=item set (key, data, [duration])
-
 =for html <a name="item_set"></a>
 
+=item set (key, data, [duration])
+
 Associates I<data> with I<key> in the cache. I<duration>
 indicates the time until the value should be erased.  If
 I<duration> is unspecified, the value will never expire
